import React, { useEffect, useState } from 'react';
import { Space, Table, Button, Input, Select, DatePicker, Tabs } from 'antd';
import type { TableProps } from 'antd';
import { Dayjs } from 'dayjs';
import styles from './index.module.css';
import PunlishPlanModal from './components/publishPlanModal';
const { RangePicker } = DatePicker;
import { useAccountOptions } from '@src/views/publishContent/weGZH/hooks/useAccountOptions';
import { useGzhPlanList, GzhPlanType } from '@src/views/publishContent/weGZH/hooks/useGzhPlanList';

const WeGZHContent: React.FC = () => {
	// 状态管理
	const [selectedAccount, setSelectedAccount] = useState<string>();
	const [videoTitle, setVideoTitle] = useState<string>('');
	const [selectedPublisher, setSelectedPublisher] = useState<string>();
	const [dateRange, setDateRange] = useState<[Dayjs | null, Dayjs | null]>();
	const [isShowAddPunlishPlan, setIsShowAddPunlishPlan] = useState<boolean>(false);
	const [actionType, setActionType] = useState<'add' | 'edit'>('add');
	const [editPlanData, setEditPlanData] = useState<GzhPlanType>();
	const [activeKey, setActiveKey] = useState<string>('1');

	const { accountOptions } = useAccountOptions();
	const { gzhPlanList, getGzhPlanList, totalSize } = useGzhPlanList();

	// 表格列配置
	const columns: TableProps<GzhPlanType>['columns'] = [
		{
			title: '公众号名称',
			dataIndex: 'accountName',
			key: 'accountName',
			width: 200,
		},
		{
			title: '场景',
			dataIndex: 'scene',
			key: 'scene',
			width: 120,
		},
		{
			title: '视频数量',
			dataIndex: 'videoCount',
			key: 'videoCount',
			width: 120,
		},
		{
			title: '视频标题',
			dataIndex: 'title',
			key: 'title',
			ellipsis: true,
		},
		{
			title: '计划创建时间',
			dataIndex: 'createTimestamp',
			key: 'createTimestamp',
			width: 200,
		},
		{
			title: '发布方',
			dataIndex: 'publishStage',
			key: 'publishStage',
			width: 120,
			render: (_, record) => {
				return record.publishStage === 1 ? '平台发布' : '用户发布';
			}
		},
		{
			title: '操作',
			key: 'action',
			width: 200,
			render: (_, record) => (
				<Space size="middle">
					<Button type="link" onClick={() => editPlan(record)}>编辑</Button>
					<Button type="link">详情</Button>
				</Space>
			),
		},
	];

	const editPlan = (record: GzhPlanType) => {
		setEditPlanData(record);
		setActionType('edit');
		setIsShowAddPunlishPlan(true);
	};

	const addPunlishPlan = () => {
		setActionType('add');
		setIsShowAddPunlishPlan(true);
	}

	useEffect(() => {
		getGzhPlanList({
			pageNum: 1,
			pageSize: 10,
		});
	}, []);

	return (
		<div>
			<div className="rounded-lg">
				<div className="text-lg font-medium mb-3">公众号内容</div>
				
				{/* 搜索区域 */}
				<div className="flex flex-wrap gap-4 mb-3">
					<div className="flex items-center gap-2">
						<span className="text-gray-600">公众号名称:</span>
						<Select
							placeholder="选择公众号"
							style={{ width: 200 }}
							value={selectedAccount}
							onChange={setSelectedAccount}
							allowClear
							options={accountOptions.map(item => ({ label: item.name, value: item.id }))}
						/>
					</div>

					<div className="flex items-center gap-2">
						<span className="text-gray-600">视频标题:</span>
						<Input
							placeholder="搜索视频标题"
							style={{ width: 200 }}
							value={videoTitle}
							allowClear
							onChange={e => setVideoTitle(e.target.value)}
						/>
					</div>

					<div className="flex items-center gap-2">
						<span className="text-gray-600">发布方:</span>
						<Select
							placeholder="选择发布方"
							style={{ width: 200 }}
							value={selectedPublisher}
							onChange={setSelectedPublisher}
							allowClear
							options={[
								{ label: '平台发布', value: 'platform' },
								{ label: '用户发布', value: 'user' },
							]}
						/>
					</div>

					<div className="flex items-center gap-2">
						<RangePicker
							placeholder={['开始时间', '结束时间']}
							style={{ width: 400 }}
							allowClear
							value={dateRange}
							onChange={(dates) => {
								setDateRange(dates || undefined);
							}}
						/>
					</div>

					<Button type="primary" className="ml-2">搜索</Button>
				</div>
				<Tabs
					defaultActiveKey="1"
					type="card"
					size="large"
					className={styles.antTableTab}
					items={[
						{ label: '自动回复', key: '1' },
					]}
					activeKey={activeKey}
					onChange={setActiveKey}
					tabBarExtraContent={
						{ right: <Button type="primary" onClick={addPunlishPlan}>+ 创建发布</Button> }}
				/>
				{/* 表格区域 */}
				<Table
					rowKey={(record) => record.id}
					className={styles.antTable}
					columns={columns}
					dataSource={gzhPlanList}
					pagination={{
						total: totalSize,
						pageSize: 10,
						showTotal: (total) => `共 ${total} 条`,
					}}
				/>
				<PunlishPlanModal
					visible={isShowAddPunlishPlan}
					onCancel={() => setIsShowAddPunlishPlan(false)}
					onOk={() => setIsShowAddPunlishPlan(false)}
					actionType={actionType}
					editPlanData={editPlanData}
				/>
			</div>
		</div>
	);
};

export default WeGZHContent;
